@@ -5,6 +5,24 @@ use warnings;
 
 
 
+########## GENERATED CONSTANTS BEGIN
+require Exporter;
+unshift @Ogre::Plane::ISA, 'Exporter';
+
+our %EXPORT_TAGS = (
+	'Side' => [qw(
+		NO_SIDE
+		POSITIVE_SIDE
+		NEGATIVE_SIDE
+		BOTH_SIDE
+	)],
+);
+
+$EXPORT_TAGS{'all'} = [ map { @{ $EXPORT_TAGS{$_} } } keys %EXPORT_TAGS ];
+our @EXPORT_OK = @{ $EXPORT_TAGS{'all'} };
+our @EXPORT = ();
+########## GENERATED CONSTANTS END
+
 1;
 
 __END__
